Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1001 was 3.70 (0.06 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    chapters-for-book:
        - chapter*.rst|jinja

    chapters-standalone:
        - chapter*.rst|jinja|rst2latex|latex

    book.rst|jinja|rst2latex|latex:
        - chapters-for-book

    book.rst|jinja|rst2html:
        - chapters-for-book

# 10 Slowest Tasks

- 0.679 - chapter-01.rst|jinja|rst2latex|latex (generated)
- 0.652 - chapter-02.rst|jinja|rst2latex|latex (generated)
- 0.624 - book.rst|jinja|rst2latex|latex (generated)
- 0.165 - book.rst|jinja|rst2html (generated)
- 0.163 - book.rst|jinja|rst2latex (generated)
- 0.155 - chapter-02.rst|jinja|rst2latex (generated)
- 0.144 - chapter-01.rst|jinja|rst2latex (generated)
- 0.033 - chapter-01.rst|jinja (generated)
- 0.022 - book.rst|jinja (generated)
- 0.021 - chapter-02.rst|jinja (generated)

# Documents

## chapter-02.rst|jinja ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
chapter-02.rst | artifacts/746e3b68e65ff26fb5a12ff1f2f3df7c.rst | 0.0000 |  |
chapter-02.rst|jinja | artifacts/e4fd5fee3628811080599be32c79ee33.rst | 0.0331 | generated |

#### Document Log

    2012-11-18 23:08:42,685 - chapter-02.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:42,687 - chapter-02.rst|jinja - DEBUG - Setting hashstring for chapter-02.rst|jinja to e4fd5fee3628811080599be32c79ee33
    2012-11-18 23:08:42,687 - chapter-02.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,966 - chapter-02.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:42,967 - chapter-02.rst|jinja - DEBUG - Setting hashstring for chapter-02.rst|jinja to a595143915d266ebc1257d48599e7092
    2012-11-18 23:08:42,967 - chapter-02.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,234 - chapter-02.rst|jinja - DEBUG - Running FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - Output is not cached under e4fd5fee3628811080599be32c79ee33, running...
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/e4fd5fee3628811080599be32c79ee33/, artifacts/e4fd5fee3628811080599be32c79ee33
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,263 - chapter-02.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - relative refs are []
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,265 - chapter-02.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,267 - chapter-02.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:44,284 - chapter-02.rst|jinja - DEBUG - Running FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:44,284 - chapter-02.rst|jinja - DEBUG - Output is not cached under a595143915d266ebc1257d48599e7092, running...
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/a595143915d266ebc1257d48599e7092/, artifacts/a595143915d266ebc1257d48599e7092
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - relative refs are []
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:44,305 - chapter-02.rst|jinja - DEBUG - about to process jinja template

## chapter-01.rst|jinja ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
chapter-01.rst | artifacts/2443b47d5f220a5731e6d48edab547c8.rst | 0.0000 |  |
chapter-01.rst|jinja | artifacts/0f37575860ab206ceb4314d7cacef142.rst | 0.0205 | generated |

#### Document Log

    2012-11-18 23:08:42,689 - chapter-01.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:42,690 - chapter-01.rst|jinja - DEBUG - Setting hashstring for chapter-01.rst|jinja to 0f37575860ab206ceb4314d7cacef142
    2012-11-18 23:08:42,690 - chapter-01.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - Setting hashstring for chapter-01.rst|jinja to 9faf5d495f22a9cfe3d845f0ab1735ca
    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,268 - chapter-01.rst|jinja - DEBUG - Running FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:43,268 - chapter-01.rst|jinja - DEBUG - Output is not cached under 0f37575860ab206ceb4314d7cacef142, running...
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/0f37575860ab206ceb4314d7cacef142/, artifacts/0f37575860ab206ceb4314d7cacef142
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,286 - chapter-01.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,286 - chapter-01.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - relative refs are ['/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,288 - chapter-01.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:45,115 - chapter-01.rst|jinja - DEBUG - Running FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:45,116 - chapter-01.rst|jinja - DEBUG - Output is not cached under 9faf5d495f22a9cfe3d845f0ab1735ca, running...
    2012-11-18 23:08:45,118 - chapter-01.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/9faf5d495f22a9cfe3d845f0ab1735ca/, artifacts/9faf5d495f22a9cfe3d845f0ab1735ca
    2012-11-18 23:08:45,118 - chapter-01.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:45,119 - chapter-01.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:45,120 - chapter-01.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:45,121 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:45,121 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:45,122 - chapter-01.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:45,123 - chapter-01.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:45,123 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:45,124 - chapter-01.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:45,124 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:45,125 - chapter-01.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:45,145 - chapter-01.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - relative refs are ['/chapter-02.rst-jinja-rst2latex-latex.pdf', '/chapter-02.rst|jinja|rst2latex|latex', 'chapter-02.rst-jinja-rst2latex-latex.pdf', 'chapter-02.rst|jinja|rst2latex|latex']
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:45,147 - chapter-01.rst|jinja - DEBUG - about to process jinja template

## book.rst|jinja|rst2latex|latex ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
book.rst | artifacts/2990bee53e4c3f3b56e9be1a796855b8.rst | 0.0000 |  |
book.rst|jinja | artifacts/169d23068e4fae126b99a30b4d7cc04f.rst | 0.0204 | generated |
book.rst|jinja|rst2latex | artifacts/f04f354efb5db90e4fe69963b8427d58.tex | 0.1626 | generated |
book.rst|jinja|rst2latex|latex | artifacts/f0802179980316c2f1da38faedbbbe41.pdf | 0.6237 | generated |

#### Document Log

    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - Setting up FilterArtifact:book.rst|jinja
    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - Setting hashstring for book.rst|jinja to 169d23068e4fae126b99a30b4d7cc04f
    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,696 - book.rst|jinja|rst2latex - DEBUG - Setting up FilterArtifact:book.rst|jinja|rst2latex
    2012-11-18 23:08:42,827 - book.rst|jinja|rst2latex - DEBUG - Setting hashstring for book.rst|jinja|rst2latex to f04f354efb5db90e4fe69963b8427d58
    2012-11-18 23:08:42,827 - book.rst|jinja|rst2latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,827 - book.rst|jinja|rst2latex|latex - DEBUG - Setting up FilterArtifact:book.rst|jinja|rst2latex|latex
    2012-11-18 23:08:42,828 - book.rst|jinja|rst2latex|latex - DEBUG - Setting hashstring for book.rst|jinja|rst2latex|latex to f0802179980316c2f1da38faedbbbe41
    2012-11-18 23:08:42,828 - book.rst|jinja|rst2latex|latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - Setting up FilterArtifact:book.rst|jinja
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - Setting hashstring for book.rst|jinja to dd07f76260ae7f2da3d39d282f977212
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,289 - book.rst|jinja - DEBUG - Running FilterArtifact:book.rst|jinja
    2012-11-18 23:08:43,289 - book.rst|jinja - DEBUG - Output is not cached under 169d23068e4fae126b99a30b4d7cc04f, running...
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/169d23068e4fae126b99a30b4d7cc04f/, artifacts/169d23068e4fae126b99a30b4d7cc04f
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,307 - book.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,307 - book.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - relative refs are ['/chapter-01.rst-jinja.rst', '/chapter-01.rst|jinja', '/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-01.rst-jinja.rst', 'chapter-01.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,309 - book.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:43,309 - book.rst|jinja|rst2latex - DEBUG - Running FilterArtifact:book.rst|jinja|rst2latex
    2012-11-18 23:08:43,310 - book.rst|jinja|rst2latex - DEBUG - Output is not cached under f04f354efb5db90e4fe69963b8427d58, running...
    2012-11-18 23:08:43,310 - book.rst|jinja|rst2latex - DEBUG - command line args specified by user are ''
    2012-11-18 23:08:43,311 - book.rst|jinja|rst2latex - DEBUG - About to run 'rst2latex.py  book.rst ' in 'artifacts/f04f354efb5db90e4fe69963b8427d58/'
    2012-11-18 23:08:43,471 - book.rst|jinja|rst2latex - DEBUG - stdout is '\documentclass[a4paper]{article}
    % generated by Docutils
    \usepackage{fixltx2e} % LaTeX patches, \textsubscript
    \usepackage{cmap} % fix search and cut-and-paste in Acrobat
    \usepackage{ifthen}
    \usepackage[T1]{fontenc}
    \usepackage[utf8]{inputenc}
    \setcounter{secnumdepth}{0}

    %%% Custom LaTeX preamble
    % PDF Standard Fonts
    \usepackage{mathptmx} % Times
    \usepackage[scaled=.90]{helvet}
    \usepackage{courier}

    %%% User specified packages and stylesheets

    %%% Fallback definitions for Docutils-specific commands

    % hyperlinks:
    \ifthenelse{\isundefined{\hypersetup}}{
      \usepackage[colorlinks=true,linkcolor=blue,urlcolor=blue]{hyperref}
      \urlstyle{same} % normal text font (alternatives: tt, rm, sf)
    }{}

    %%% Body
    \begin{document}

    This is the book.

    \section{Chapter 1 Title%
      \label{chapter-1-title}%
    }

    This is content of chapter 1.
    %
    \begin{itemize}

    \item item

    \item another

    \end{itemize}

    \section{Chapter 2 Title%
      \label{chapter-2-title}%
    }

    This is chapter 2.
    \newcounter{listcnt0}
    \begin{list}{\arabic{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item numbers
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\Alph{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item upper-case letters
    and it goes over many lines

    with two paragraphs and all!
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\alph{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item %
    \begin{description}
    \item[{lower-case letters}] \leavevmode \newcounter{listcnt1}
    \begin{list}{\arabic{listcnt1}.}
    {
    \usecounter{listcnt1}
    \addtocounter{listcnt1}{2}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item with a sub-list starting at a different number

    \item make sure the numbers are in the correct sequence though!
    \end{list}

    \end{description}
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\Roman{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item upper-case roman numerals
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\roman{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item lower-case roman numerals
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{(\arabic{listcnt0})}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item numbers again
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\arabic{listcnt0})}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item and again
    \end{list}

    This is the end of the book.

    \end{document}
    '
    2012-11-18 23:08:43,472 - book.rst|jinja|rst2latex - DEBUG - stderr is ''
    2012-11-18 23:08:43,472 - book.rst|jinja|rst2latex|latex - DEBUG - Running FilterArtifact:book.rst|jinja|rst2latex|latex
    2012-11-18 23:08:43,472 - book.rst|jinja|rst2latex|latex - DEBUG - Output is not cached under f0802179980316c2f1da38faedbbbe41, running...
    2012-11-18 23:08:43,473 - book.rst|jinja|rst2latex|latex - DEBUG - Command line args specified by user ''
    2012-11-18 23:08:43,474 - book.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  book.tex in artifacts/f0802179980316c2f1da38faedbbbe41/
    2012-11-18 23:08:43,614 - book.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:43,614 - book.rst|jinja|rst2latex|latex - INFO - running bibtex book in artifacts/f0802179980316c2f1da38faedbbbe41/
    2012-11-18 23:08:43,673 - book.rst|jinja|rst2latex|latex - DEBUG - This is BibTeX, Version 0.99d (TeX Live 2012)
    The top-level auxiliary file: book.aux
    I found no \citation commands---while reading file book.aux
    I found no \bibdata command---while reading file book.aux
    I found no \bibstyle command---while reading file book.aux
    (There were 3 error messages)

    2012-11-18 23:08:43,673 - book.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  book.tex in artifacts/f0802179980316c2f1da38faedbbbe41/
    2012-11-18 23:08:43,813 - book.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:43,813 - book.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  book.tex in artifacts/f0802179980316c2f1da38faedbbbe41/
    2012-11-18 23:08:43,954 - book.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:43,955 - book.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  book.tex in artifacts/f0802179980316c2f1da38faedbbbe41/
    2012-11-18 23:08:44,095 - book.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - Running FilterArtifact:book.rst|jinja
    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - Output is not cached under dd07f76260ae7f2da3d39d282f977212, running...
    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/dd07f76260ae7f2da3d39d282f977212/, artifacts/dd07f76260ae7f2da3d39d282f977212
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - relative refs are ['/chapter-01.rst-jinja.rst', '/chapter-01.rst|jinja', '/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-01.rst-jinja.rst', 'chapter-01.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:44,118 - book.rst|jinja - DEBUG - about to process jinja template

## book.rst|jinja|rst2html ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
book.rst | artifacts/2990bee53e4c3f3b56e9be1a796855b8.rst | 0.0000 |  |
book.rst|jinja | artifacts/dd07f76260ae7f2da3d39d282f977212.rst | 0.0216 | generated |
book.rst|jinja|rst2html | artifacts/484b9f9945fd2f8f8f87787ac6358329.html | 0.1651 | generated |

#### Document Log

#

#

    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - Setting up FilterArtifact:book.rst|jinja
    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - Setting hashstring for book.rst|jinja to 169d23068e4fae126b99a30b4d7cc04f
    2012-11-18 23:08:42,695 - book.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - Setting up FilterArtifact:book.rst|jinja
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - Setting hashstring for book.rst|jinja to dd07f76260ae7f2da3d39d282f977212
    2012-11-18 23:08:42,829 - book.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,829 - book.rst|jinja|rst2html - DEBUG - Setting up FilterArtifact:book.rst|jinja|rst2html
    2012-11-18 23:08:42,965 - book.rst|jinja|rst2html - DEBUG - Setting hashstring for book.rst|jinja|rst2html to 484b9f9945fd2f8f8f87787ac6358329
    2012-11-18 23:08:42,966 - book.rst|jinja|rst2html - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,289 - book.rst|jinja - DEBUG - Running FilterArtifact:book.rst|jinja
    2012-11-18 23:08:43,289 - book.rst|jinja - DEBUG - Output is not cached under 169d23068e4fae126b99a30b4d7cc04f, running...
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/169d23068e4fae126b99a30b4d7cc04f/, artifacts/169d23068e4fae126b99a30b4d7cc04f
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,290 - book.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,291 - book.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,307 - book.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,307 - book.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - relative refs are ['/chapter-01.rst-jinja.rst', '/chapter-01.rst|jinja', '/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-01.rst-jinja.rst', 'chapter-01.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,308 - book.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,309 - book.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - Running FilterArtifact:book.rst|jinja
    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - Output is not cached under dd07f76260ae7f2da3d39d282f977212, running...
    2012-11-18 23:08:44,097 - book.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/dd07f76260ae7f2da3d39d282f977212/, artifacts/dd07f76260ae7f2da3d39d282f977212
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:44,098 - book.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:44,099 - book.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:44,116 - book.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - relative refs are ['/chapter-01.rst-jinja.rst', '/chapter-01.rst|jinja', '/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-01.rst-jinja.rst', 'chapter-01.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:44,117 - book.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:44,118 - book.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:44,118 - book.rst|jinja|rst2html - DEBUG - Running FilterArtifact:book.rst|jinja|rst2html
    2012-11-18 23:08:44,118 - book.rst|jinja|rst2html - DEBUG - Output is not cached under 484b9f9945fd2f8f8f87787ac6358329, running...
    2012-11-18 23:08:44,119 - book.rst|jinja|rst2html - DEBUG - command line args specified by user are ''
    2012-11-18 23:08:44,119 - book.rst|jinja|rst2html - DEBUG - About to run 'rst2html.py  book.rst ' in 'artifacts/484b9f9945fd2f8f8f87787ac6358329/'
    2012-11-18 23:08:44,283 - book.rst|jinja|rst2html - DEBUG - stdout is '

    This is the book.

    Chapter 1 Title
    This is content of chapter 1.

    item
    another

    Chapter 2 Title
    This is chapter 2.

    numbers

    upper-case letters
    and it goes over many lines
    with two paragraphs and all!

    lower-case letters

    with a sub-list starting at a different number
    make sure the numbers are in the correct sequence though!

    upper-case roman numerals

    lower-case roman numerals

    numbers again

    and again

    This is the end of the book.

    '
    2012-11-18 23:08:44,283 - book.rst|jinja|rst2html - DEBUG - stderr is ''

## chapter-02.rst|jinja|rst2latex|latex ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
chapter-02.rst | artifacts/746e3b68e65ff26fb5a12ff1f2f3df7c.rst | 0.0000 |  |
chapter-02.rst|jinja | artifacts/a595143915d266ebc1257d48599e7092.rst | 0.0213 | generated |
chapter-02.rst|jinja|rst2latex | artifacts/7e85e088dad74d337cb7f189ac1513d2.tex | 0.1546 | generated |
chapter-02.rst|jinja|rst2latex|latex | artifacts/1efb45aaa116efdc9857f5dea7f86920.pdf | 0.6525 | generated |

#### Document Log

    2012-11-18 23:08:42,966 - chapter-02.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:42,967 - chapter-02.rst|jinja - DEBUG - Setting hashstring for chapter-02.rst|jinja to a595143915d266ebc1257d48599e7092
    2012-11-18 23:08:42,967 - chapter-02.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:42,967 - chapter-02.rst|jinja|rst2latex - DEBUG - Setting up FilterArtifact:chapter-02.rst|jinja|rst2latex
    2012-11-18 23:08:43,099 - chapter-02.rst|jinja|rst2latex - DEBUG - Setting hashstring for chapter-02.rst|jinja|rst2latex to 7e85e088dad74d337cb7f189ac1513d2
    2012-11-18 23:08:43,099 - chapter-02.rst|jinja|rst2latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,099 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - Setting up FilterArtifact:chapter-02.rst|jinja|rst2latex|latex
    2012-11-18 23:08:43,100 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - Setting hashstring for chapter-02.rst|jinja|rst2latex|latex to 1efb45aaa116efdc9857f5dea7f86920
    2012-11-18 23:08:43,100 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,234 - chapter-02.rst|jinja - DEBUG - Running FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - Output is not cached under e4fd5fee3628811080599be32c79ee33, running...
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/e4fd5fee3628811080599be32c79ee33/, artifacts/e4fd5fee3628811080599be32c79ee33
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,235 - chapter-02.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,236 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,237 - chapter-02.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,263 - chapter-02.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - relative refs are []
    2012-11-18 23:08:43,264 - chapter-02.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,265 - chapter-02.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,267 - chapter-02.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:44,284 - chapter-02.rst|jinja - DEBUG - Running FilterArtifact:chapter-02.rst|jinja
    2012-11-18 23:08:44,284 - chapter-02.rst|jinja - DEBUG - Output is not cached under a595143915d266ebc1257d48599e7092, running...
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/a595143915d266ebc1257d48599e7092/, artifacts/a595143915d266ebc1257d48599e7092
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:44,285 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:44,286 - chapter-02.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:44,303 - chapter-02.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - relative refs are []
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:44,304 - chapter-02.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:44,305 - chapter-02.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:44,305 - chapter-02.rst|jinja|rst2latex - DEBUG - Running FilterArtifact:chapter-02.rst|jinja|rst2latex
    2012-11-18 23:08:44,306 - chapter-02.rst|jinja|rst2latex - DEBUG - Output is not cached under 7e85e088dad74d337cb7f189ac1513d2, running...
    2012-11-18 23:08:44,306 - chapter-02.rst|jinja|rst2latex - DEBUG - command line args specified by user are ''
    2012-11-18 23:08:44,306 - chapter-02.rst|jinja|rst2latex - DEBUG - About to run 'rst2latex.py  chapter-02.rst ' in 'artifacts/7e85e088dad74d337cb7f189ac1513d2/'
    2012-11-18 23:08:44,459 - chapter-02.rst|jinja|rst2latex - DEBUG - stdout is '\documentclass[a4paper]{article}
    % generated by Docutils
    \usepackage{fixltx2e} % LaTeX patches, \textsubscript
    \usepackage{cmap} % fix search and cut-and-paste in Acrobat
    \usepackage{ifthen}
    \usepackage[T1]{fontenc}
    \usepackage[utf8]{inputenc}

    %%% Custom LaTeX preamble
    % PDF Standard Fonts
    \usepackage{mathptmx} % Times
    \usepackage[scaled=.90]{helvet}
    \usepackage{courier}

    %%% User specified packages and stylesheets

    %%% Fallback definitions for Docutils-specific commands

    % hyperlinks:
    \ifthenelse{\isundefined{\hypersetup}}{
      \usepackage[colorlinks=true,linkcolor=blue,urlcolor=blue]{hyperref}
      \urlstyle{same} % normal text font (alternatives: tt, rm, sf)
    }{}
    \hypersetup{
      pdftitle={Chapter 2 Title},
    }

    %%% Title Data
    \title{\phantomsection%
      Chapter 2 Title%
      \label{chapter-2-title}}
    \author{}
    \date{}

    %%% Body
    \begin{document}
    \maketitle

    This is chapter 2.
    \newcounter{listcnt0}
    \begin{list}{\arabic{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item numbers
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\Alph{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item upper-case letters
    and it goes over many lines

    with two paragraphs and all!
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\alph{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item %
    \begin{description}
    \item[{lower-case letters}] \leavevmode \newcounter{listcnt1}
    \begin{list}{\arabic{listcnt1}.}
    {
    \usecounter{listcnt1}
    \addtocounter{listcnt1}{2}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item with a sub-list starting at a different number

    \item make sure the numbers are in the correct sequence though!
    \end{list}

    \end{description}
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\Roman{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item upper-case roman numerals
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\roman{listcnt0}.}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item lower-case roman numerals
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{(\arabic{listcnt0})}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item numbers again
    \end{list}
    \setcounter{listcnt0}{0}
    \begin{list}{\arabic{listcnt0})}
    {
    \usecounter{listcnt0}
    \setlength{\rightmargin}{\leftmargin}
    }

    \item and again
    \end{list}

    \end{document}
    '
    2012-11-18 23:08:44,460 - chapter-02.rst|jinja|rst2latex - DEBUG - stderr is ''
    2012-11-18 23:08:44,460 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - Running FilterArtifact:chapter-02.rst|jinja|rst2latex|latex
    2012-11-18 23:08:44,460 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - Output is not cached under 1efb45aaa116efdc9857f5dea7f86920, running...
    2012-11-18 23:08:44,461 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - Command line args specified by user ''
    2012-11-18 23:08:44,461 - chapter-02.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-02.tex in artifacts/1efb45aaa116efdc9857f5dea7f86920/
    2012-11-18 23:08:44,610 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:44,610 - chapter-02.rst|jinja|rst2latex|latex - INFO - running bibtex chapter-02 in artifacts/1efb45aaa116efdc9857f5dea7f86920/
    2012-11-18 23:08:44,666 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - This is BibTeX, Version 0.99d (TeX Live 2012)
    The top-level auxiliary file: chapter-02.aux
    I found no \citation commands---while reading file chapter-02.aux
    I found no \bibdata command---while reading file chapter-02.aux
    I found no \bibstyle command---while reading file chapter-02.aux
    (There were 3 error messages)

    2012-11-18 23:08:44,667 - chapter-02.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-02.tex in artifacts/1efb45aaa116efdc9857f5dea7f86920/
    2012-11-18 23:08:44,815 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:44,815 - chapter-02.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-02.tex in artifacts/1efb45aaa116efdc9857f5dea7f86920/
    2012-11-18 23:08:44,956 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:44,956 - chapter-02.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-02.tex in artifacts/1efb45aaa116efdc9857f5dea7f86920/
    2012-11-18 23:08:45,111 - chapter-02.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

## chapter-01.rst|jinja|rst2latex|latex ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections
--- | --- | --- | --- | ---
chapter-01.rst | artifacts/2443b47d5f220a5731e6d48edab547c8.rst | 0.0001 |  |
chapter-01.rst|jinja | artifacts/9faf5d495f22a9cfe3d845f0ab1735ca.rst | 0.0325 | generated |
chapter-01.rst|jinja|rst2latex | artifacts/88abdf399b043d52475172a931f0196e.tex | 0.1443 | generated |
chapter-01.rst|jinja|rst2latex|latex | artifacts/72d2d51b60460e2cf9c46992e0711e2d.pdf | 0.6793 | generated |

#### Document Log

    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - Setting up FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - Setting hashstring for chapter-01.rst|jinja to 9faf5d495f22a9cfe3d845f0ab1735ca
    2012-11-18 23:08:43,101 - chapter-01.rst|jinja - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,102 - chapter-01.rst|jinja|rst2latex - DEBUG - Setting up FilterArtifact:chapter-01.rst|jinja|rst2latex
    2012-11-18 23:08:43,232 - chapter-01.rst|jinja|rst2latex - DEBUG - Setting hashstring for chapter-01.rst|jinja|rst2latex to 88abdf399b043d52475172a931f0196e
    2012-11-18 23:08:43,233 - chapter-01.rst|jinja|rst2latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,233 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - Setting up FilterArtifact:chapter-01.rst|jinja|rst2latex|latex
    2012-11-18 23:08:43,234 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - Setting hashstring for chapter-01.rst|jinja|rst2latex|latex to 72d2d51b60460e2cf9c46992e0711e2d
    2012-11-18 23:08:43,234 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - setting up output data of class GenericData
    2012-11-18 23:08:43,268 - chapter-01.rst|jinja - DEBUG - Running FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:43,268 - chapter-01.rst|jinja - DEBUG - Output is not cached under 0f37575860ab206ceb4314d7cacef142, running...
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/0f37575860ab206ceb4314d7cacef142/, artifacts/0f37575860ab206ceb4314d7cacef142
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:43,269 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:43,270 - chapter-01.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:43,286 - chapter-01.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:43,286 - chapter-01.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - relative refs are ['/chapter-02.rst-jinja.rst', '/chapter-02.rst|jinja', 'chapter-02.rst-jinja.rst', 'chapter-02.rst|jinja']
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:43,287 - chapter-01.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:43,288 - chapter-01.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:45,115 - chapter-01.rst|jinja - DEBUG - Running FilterArtifact:chapter-01.rst|jinja
    2012-11-18 23:08:45,116 - chapter-01.rst|jinja - DEBUG - Output is not cached under 9faf5d495f22a9cfe3d845f0ab1735ca, running...
    2012-11-18 23:08:45,118 - chapter-01.rst|jinja - DEBUG - setting up jinja FileSystemLoader with dirs artifacts/9faf5d495f22a9cfe3d845f0ab1735ca/, artifacts/9faf5d495f22a9cfe3d845f0ab1735ca
    2012-11-18 23:08:45,118 - chapter-01.rst|jinja - DEBUG - setting up jinja environment
    2012-11-18 23:08:45,119 - chapter-01.rst|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-18 23:08:45,120 - chapter-01.rst|jinja - DEBUG - initializing template
    2012-11-18 23:08:45,121 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-18 23:08:45,121 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-18 23:08:45,122 - chapter-01.rst|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-18 23:08:45,123 - chapter-01.rst|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-18 23:08:45,123 - chapter-01.rst|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-18 23:08:45,124 - chapter-01.rst|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-18 23:08:45,124 - chapter-01.rst|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-18 23:08:45,125 - chapter-01.rst|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-18 23:08:45,145 - chapter-01.rst|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Variables
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Globals
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - Running template plugin Inputs
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - relative refs are ['/chapter-02.rst-jinja-rst2latex-latex.pdf', '/chapter-02.rst|jinja|rst2latex|latex', 'chapter-02.rst-jinja-rst2latex-latex.pdf', 'chapter-02.rst|jinja|rst2latex|latex']
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-18 23:08:45,146 - chapter-01.rst|jinja - DEBUG - about to create jinja template
    2012-11-18 23:08:45,147 - chapter-01.rst|jinja - DEBUG - about to process jinja template
    2012-11-18 23:08:45,148 - chapter-01.rst|jinja|rst2latex - DEBUG - Running FilterArtifact:chapter-01.rst|jinja|rst2latex
    2012-11-18 23:08:45,148 - chapter-01.rst|jinja|rst2latex - DEBUG - Output is not cached under 88abdf399b043d52475172a931f0196e, running...
    2012-11-18 23:08:45,148 - chapter-01.rst|jinja|rst2latex - DEBUG - command line args specified by user are ''
    2012-11-18 23:08:45,149 - chapter-01.rst|jinja|rst2latex - DEBUG - About to run 'rst2latex.py  chapter-01.rst ' in 'artifacts/88abdf399b043d52475172a931f0196e/'
    2012-11-18 23:08:45,291 - chapter-01.rst|jinja|rst2latex - DEBUG - stdout is '\documentclass[a4paper]{article}
    % generated by Docutils
    \usepackage{fixltx2e} % LaTeX patches, \textsubscript
    \usepackage{cmap} % fix search and cut-and-paste in Acrobat
    \usepackage{ifthen}
    \usepackage[T1]{fontenc}
    \usepackage[utf8]{inputenc}

    %%% Custom LaTeX preamble
    % PDF Standard Fonts
    \usepackage{mathptmx} % Times
    \usepackage[scaled=.90]{helvet}
    \usepackage{courier}

    %%% User specified packages and stylesheets

    %%% Fallback definitions for Docutils-specific commands

    % hyperlinks:
    \ifthenelse{\isundefined{\hypersetup}}{
      \usepackage[colorlinks=true,linkcolor=blue,urlcolor=blue]{hyperref}
      \urlstyle{same} % normal text font (alternatives: tt, rm, sf)
    }{}
    \hypersetup{
      pdftitle={Chapter 1 Title},
    }

    %%% Title Data
    \title{\phantomsection%
      Chapter 1 Title%
      \label{chapter-1-title}}
    \author{}
    \date{}

    %%% Body
    \begin{document}
    \maketitle

    This is content of chapter 1.
    %
    \begin{itemize}

    \item item

    \item another

    \end{itemize}

    \end{document}
    '
    2012-11-18 23:08:45,292 - chapter-01.rst|jinja|rst2latex - DEBUG - stderr is ''
    2012-11-18 23:08:45,292 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - Running FilterArtifact:chapter-01.rst|jinja|rst2latex|latex
    2012-11-18 23:08:45,292 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - Output is not cached under 72d2d51b60460e2cf9c46992e0711e2d, running...
    2012-11-18 23:08:45,293 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - Command line args specified by user ''
    2012-11-18 23:08:45,293 - chapter-01.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-01.tex in artifacts/72d2d51b60460e2cf9c46992e0711e2d/
    2012-11-18 23:08:45,433 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:45,434 - chapter-01.rst|jinja|rst2latex|latex - INFO - running bibtex chapter-01 in artifacts/72d2d51b60460e2cf9c46992e0711e2d/
    2012-11-18 23:08:45,491 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - This is BibTeX, Version 0.99d (TeX Live 2012)
    The top-level auxiliary file: chapter-01.aux
    I found no \citation commands---while reading file chapter-01.aux
    I found no \bibdata command---while reading file chapter-01.aux
    I found no \bibstyle command---while reading file chapter-01.aux
    (There were 3 error messages)

    2012-11-18 23:08:45,492 - chapter-01.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-01.tex in artifacts/72d2d51b60460e2cf9c46992e0711e2d/
    2012-11-18 23:08:45,647 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:45,648 - chapter-01.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-01.tex in artifacts/72d2d51b60460e2cf9c46992e0711e2d/
    2012-11-18 23:08:45,790 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode

    2012-11-18 23:08:45,791 - chapter-01.rst|jinja|rst2latex|latex - INFO - running pdflatex -interaction=batchmode  chapter-01.tex in artifacts/72d2d51b60460e2cf9c46992e0711e2d/
    2012-11-18 23:08:45,971 - chapter-01.rst|jinja|rst2latex|latex - DEBUG - This is pdfTeX, Version 3.1415926-2.4-1.40.13 (TeX Live 2012)
     restricted \write18 enabled.
    entering extended mode